==> risecx_chat_client-1.2.1%2B1.tar.gz: lib/widgets/chat/messages_types/quickreply_message_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:risecx_chat_client/models/messages/messages.dart';
import 'package:risecx_chat_client/styles.dart';

class QuickReplyMessageWidget extends StatefulWidget {
  final dynamic message;
  final Function onPayloadPress;
  const QuickReplyMessageWidget({Key key, this.message, this.onPayloadPress})
      : super(key: key);

  @override
  _QuickReplyMessageWidgetState createState() =>
      _QuickReplyMessageWidgetState();
}

class _QuickReplyMessageWidgetState extends State<QuickReplyMessageWidget> {
  QuickReplyMessageModel _quickReplyModel;

  @override
  Widget build(BuildContext context) {
    _quickReplyModel = QuickReplyMessageModel.fromJson(widget.message);
    return Card(
        child: Column(
      children: <Widget>[
        Padding(
          child:
              Text(_quickReplyModel.text, style: Styles.messageTitleTextStyle),
          padding: Styles.massageTitlePadding,
        ),
        Column(
          children: buttons(),
        )
      ],
    ));
  }

  quickReplyBtn(QuickReplies quickReply) {
    return SizedBox(
        width: double.infinity,
        child: Padding(
            padding: EdgeInsets.symmetric(horizontal: 10.0),
            child: OutlineButton(
              child: Text(quickReply.title),
              onPressed: () {
                widget.onPayloadPress(quickReply);
              },
            )));
  }

  List<Widget> buttons() {
    List<Widget> btnsList = new List();
    if (_quickReplyModel.quickReplies != null)
      _quickReplyModel.quickReplies
          .forEach((quickReply) => btnsList.add(quickReplyBtn(quickReply)));
    return btnsList;
  }
}

==> risecx_chat_client-1.2.3%2B1.tar.gz: lib/widgets/chat/messages_types/quickreply_message_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:risecx_chat_client/models/messages/messages.dart';
import 'package:risecx_chat_client/styles.dart';

class QuickReplyMessageWidget extends StatefulWidget {
  final dynamic message;
  final Function onPayloadPress;
  const QuickReplyMessageWidget({Key key, this.message, this.onPayloadPress})
      : super(key: key);

  @override
  _QuickReplyMessageWidgetState createState() =>
      _QuickReplyMessageWidgetState();
}

class _QuickReplyMessageWidgetState extends State<QuickReplyMessageWidget> {
  QuickReplyMessageModel _quickReplyModel;

  @override
  Widget build(BuildContext context) {
    _quickReplyModel = QuickReplyMessageModel.fromJson(widget.message);
    return Card(
        elevation: 0.0,
        color: Colors.transparent,
        child: Column(
          children: <Widget>[
            Padding(
              child: Text(_quickReplyModel.text,
                  style: Styles.messageTitleTextStyle),
              padding: Styles.massageTitlePadding,
            ),
            Column(
              children: buttons(),
            )
          ],
        ));
  }

  quickReplyBtn(QuickReplies quickReply) {
    return SizedBox(
        width: double.infinity,
        child: Padding(
            padding: EdgeInsets.symmetric(horizontal: 10.0),
            child: OutlineButton(
              borderSide: BorderSide(
                color: Color(0xFF895ff0),
              ),
              textColor: Color(0xFF895ff0),
              splashColor: Color(0x66895ff0),
              child: Text(quickReply.title),
              onPressed: () {
                widget.onPayloadPress(quickReply);
              },
            )));
  }

  List<Widget> buttons() {
    List<Widget> btnsList = new List();
    if (_quickReplyModel.quickReplies != null)
      _quickReplyModel.quickReplies
          .forEach((quickReply) => btnsList.add(quickReplyBtn(quickReply)));
    return btnsList;
  }
}
